@@ -59,6 +59,10 @@ class SaltCMD(parsers.SaltCMDOptionParser):
             self._run_batch()
             return
 
+        if self.options.preview_target:
+            self._preview_target()
+            return
+
         if self.options.timeout <= 0:
             self.options.timeout = self.local_client.opts['timeout']
 
@@ -80,9 +84,9 @@ class SaltCMD(parsers.SaltCMDOptionParser):
         kwargs['delimiter'] = self.options.delimiter
 
         if self.selected_target_option:
-            kwargs['expr_form'] = self.selected_target_option
+            kwargs['tgt_type'] = self.selected_target_option
         else:
-            kwargs['expr_form'] = 'glob'
+            kwargs['tgt_type'] = 'glob'
 
         if getattr(self.options, 'return'):
             kwargs['ret'] = getattr(self.options, 'return')
@@ -194,6 +198,13 @@ class SaltCMD(parsers.SaltCMDOptionParser):
             ret = str(exc)
             self._output_ret(ret, '')
 
+    def _preview_target(self):
+        '''
+        Return a list of minions from a given target
+        '''
+        minion_list = self.local_client.gather_minions(self.config['tgt'], self.selected_target_option or 'glob')
+        self._output_ret(minion_list, self.config.get('output', 'nested'))
+
     def _run_batch(self):
         import salt.cli.batch
         eauth = {}
@@ -281,7 +292,9 @@ class SaltCMD(parsers.SaltCMDOptionParser):
         not_connected_minions = []
         failed_minions = []
         for each_minion in ret:
-            minion_ret = ret[each_minion].get('ret')
+            minion_ret = ret[each_minion]
+            if isinstance(minion_ret, dict) and 'ret' in minion_ret:
+                minion_ret = ret[each_minion].get('ret')
             if (
                     isinstance(minion_ret, string_types)
                     and minion_ret.startswith("Minion did not return")
