@@ -72,6 +72,12 @@ class SSHHighState(salt.state.BaseHighState):
         self.matcher = salt.minion.Matcher(self.opts)
         self.tops = salt.loader.tops(self.opts)
 
+        self._pydsl_all_decls = {}
+        self._pydsl_render_stack = []
+
+    def push_active(self):
+        salt.state.HighState.stack.append(self)
+
     def load_dynamic(self, matches):
         '''
         Stub out load_dynamic
@@ -199,7 +205,7 @@ def prep_trans_tar(opts, file_client, chunks, file_refs, pillar=None, id_=None):
             os.makedirs(env_root)
         for ref in file_refs[saltenv]:
             for name in ref:
-                short = salt.utils.url.parse(name)[0]
+                short = salt.utils.url.parse(name)[0].lstrip('/')
                 cache_dest = os.path.join(cache_dest_root, short)
                 try:
                     path = file_client.cache_file(name, saltenv, cachedir=cachedir)
