@@ -144,8 +144,8 @@ import logging
 from copy import deepcopy
 import json
 
-# Import Salt Libs
-from salt.ext.six import string_types  # pylint: disable=import-error
+# Import Salt libs
+from salt.ext import six
 
 log = logging.getLogger(__name__)
 
@@ -318,20 +318,7 @@ def _compare_acl(current, desired, region, key, keyid, profile):
 
 
 def _compare_policy(current, desired, region, key, keyid, profile):
-    '''
-    Policy description is always returned as a JSON string. Comparison
-    should be object-to-object, since order is not significant in JSON
-    '''
-    if isinstance(desired, string_types):
-        desired = json.loads(desired)
-
-    if current is not None:
-        temp = current.get('Policy')
-        if isinstance(temp, string_types):
-            current = {'Policy': json.loads(temp)}
-        else:
-            current = None
-    return __utils__['boto3.json_objs_equal'](current, desired)
+    return current == desired
 
 
 def _compare_replication(current, desired, region, key, keyid, profile):
@@ -434,6 +421,10 @@ def present(name, Bucket,
         NotificationConfiguration = {}
     if RequestPayment is None:
         RequestPayment = {'Payer': 'BucketOwner'}
+    if Policy:
+        if isinstance(Policy, six.string_types):
+            Policy = json.loads(Policy)
+        Policy = __utils__['boto3.ordered'](Policy)
 
     r = __salt__['boto_s3_bucket.exists'](Bucket=Bucket,
            region=region, key=key, keyid=keyid, profile=profile)
@@ -552,14 +543,17 @@ def present(name, Bucket,
         config_items.append(replication_item)
         config_items.append(versioning_item)
 
+    update = False
     for varname, setter, current, comparator, desired, deleter in config_items:
+        if varname == 'Policy':
+            if current is not None:
+                temp = current.get('Policy')
+                # Policy description is always returned as a JSON string.
+                # Convert it to JSON now for ease of comparisons later.
+                if isinstance(temp, six.string_types):
+                    current = __utils__['boto3.ordered']({'Policy': json.loads(temp)})
         if not comparator(current, desired, region, key, keyid, profile):
-            # current state and desired state differ
-            if __opts__['test']:
-                msg = 'S3 bucket {0} set to be modified.'.format(Bucket)
-                ret['comment'] = msg
-                ret['result'] = None
-                return ret
+            update = True
             if varname == 'ACL':
                 ret['changes'].setdefault('new', {})[varname] = _acl_to_grant(
                         desired, _get_canonical_id(region, key, keyid, profile))
@@ -567,24 +561,30 @@ def present(name, Bucket,
                 ret['changes'].setdefault('new', {})[varname] = desired
             ret['changes'].setdefault('old', {})[varname] = current
 
-            if deleter and desired is None:
-                # Setting can be deleted, so use that to unset it
-                r = __salt__['boto_s3_bucket.{0}'.format(deleter)](Bucket=Bucket,
-                   region=region, key=key, keyid=keyid, profile=profile)
-                if not r.get('deleted'):
-                    ret['result'] = False
-                    ret['comment'] = 'Failed to update bucket: {0}.'.format(r['error']['message'])
-                    ret['changes'] = {}
-                    return ret
-            else:
-                r = __salt__['boto_s3_bucket.{0}'.format(setter)](Bucket=Bucket,
-                   region=region, key=key, keyid=keyid, profile=profile,
-                   **(desired or {}))
-                if not r.get('updated'):
-                    ret['result'] = False
-                    ret['comment'] = 'Failed to update bucket: {0}.'.format(r['error']['message'])
-                    ret['changes'] = {}
-                    return ret
+            if not __opts__['test']:
+                if deleter and desired is None:
+                    # Setting can be deleted, so use that to unset it
+                    r = __salt__['boto_s3_bucket.{0}'.format(deleter)](Bucket=Bucket,
+                      region=region, key=key, keyid=keyid, profile=profile)
+                    if not r.get('deleted'):
+                        ret['result'] = False
+                        ret['comment'] = 'Failed to update bucket: {0}.'.format(r['error']['message'])
+                        ret['changes'] = {}
+                        return ret
+                else:
+                    r = __salt__['boto_s3_bucket.{0}'.format(setter)](Bucket=Bucket,
+                      region=region, key=key, keyid=keyid, profile=profile,
+                      **(desired or {}))
+                    if not r.get('updated'):
+                        ret['result'] = False
+                        ret['comment'] = 'Failed to update bucket: {0}.'.format(r['error']['message'])
+                        ret['changes'] = {}
+                        return ret
+    if update and __opts__['test']:
+        msg = 'S3 bucket {0} set to be modified.'.format(Bucket)
+        ret['comment'] = msg
+        ret['result'] = None
+        return ret
 
     # Since location can't be changed, try that last so at least the rest of
     # the things are correct by the time we fail here. Fail so the user will
