@@ -29,11 +29,15 @@ from json import loads, dumps
 
 # salt lib
 from salt.ext import six
+# import NAPALM utils
+import salt.utils.napalm
 
 # ----------------------------------------------------------------------------------------------------------------------
 # state properties
 # ----------------------------------------------------------------------------------------------------------------------
 
+__virtualname__ = 'netusers'
+
 # ----------------------------------------------------------------------------------------------------------------------
 # global variables
 # ----------------------------------------------------------------------------------------------------------------------
@@ -44,7 +48,10 @@ from salt.ext import six
 
 
 def __virtual__():
-    return 'netusers'
+    '''
+    NAPALM library must be installed for this module to work and run in a (proxy) minion.
+    '''
+    return salt.utils.napalm.virtual(__opts__, __virtualname__, __file__)
 
 # ----------------------------------------------------------------------------------------------------------------------
 # helper functions -- will not be exported
@@ -111,8 +118,8 @@ def _compute_diff(configured, expected):
     remove_usernames = configured_users - expected_users
     common_usernames = expected_users & configured_users
 
-    add = dict((username, expected.get(username)) for (username, _) in add_usernames)
-    remove = dict((username, configured.get(username)) for (username, _) in remove_usernames)
+    add = dict((username, expected.get(username)) for username in add_usernames)
+    remove = dict((username, configured.get(username)) for username in remove_usernames)
     update = {}
 
     for username in common_usernames:
