@@ -481,7 +481,6 @@ def container_setting(name, container, settings=None):
     :param str container: The type of IIS container. The container types are:
         AppPools, Sites, SslBindings
     :param str settings: A dictionary of the setting names and their values.
-
     Example of usage for the ``AppPools`` container:
 
     .. code-block:: yaml
@@ -495,6 +494,7 @@ def container_setting(name, container, settings=None):
                     processModel.maxProcesses: 1
                     processModel.userName: TestUser
                     processModel.password: TestPassword
+                    processModel.identityType: SpecificUser
 
     Example of usage for the ``Sites`` container:
 
@@ -509,6 +509,8 @@ def container_setting(name, container, settings=None):
                     logFile.period: Daily
                     limits.maxUrlSegments: 32
     '''
+
+    identityType_map2string = {0: 'LocalSystem', 1: 'LocalService', 2: 'NetworkService', 3: 'SpecificUser', 4: 'ApplicationPoolIdentity'}
     ret = {'name': name,
            'changes': {},
            'comment': str(),
@@ -528,6 +530,10 @@ def container_setting(name, container, settings=None):
                                                                  container=container,
                                                                  settings=settings.keys())
     for setting in settings:
+        # map identity type from numeric to string for comparing
+        if setting == 'processModel.identityType' and settings[setting] in identityType_map2string.keys():
+            settings[setting] = identityType_map2string[settings[setting]]
+
         if str(settings[setting]) != str(current_settings[setting]):
             ret_settings['changes'][setting] = {'old': current_settings[setting],
                                                 'new': settings[setting]}
@@ -540,8 +546,8 @@ def container_setting(name, container, settings=None):
         ret['changes'] = ret_settings
         return ret
 
-    __salt__['win_iis.set_container_setting'](name=name, container=container,
-                                              settings=settings)
+    __salt__['win_iis.set_container_setting'](name=name, container=container, settings=settings)
+
     new_settings = __salt__['win_iis.get_container_setting'](name=name,
                                                              container=container,
                                                              settings=settings.keys())
@@ -768,3 +774,85 @@ def remove_vdir(name, site, app='/'):
         ret['result'] = __salt__['win_iis.remove_vdir'](name, site, app)
 
     return ret
+
+
+def set_app(name, site, settings=None):
+    r'''
+    Set the value of the setting for an IIS web application.
+    .. note::
+        This function only configures existing app.
+        Params are case sensitive.
+    :param str name: The IIS application.
+    :param str site: The IIS site name.
+    :param str settings: A dictionary of the setting names and their values.
+    :available settings:    physicalPath: The physical path of the webapp.
+    :                       applicationPool: The application pool for the webapp.
+    :                       userName: "connectAs" user
+    :                       password: "connectAs" password for user
+    :rtype: bool
+    .. versionadded:: 2017.7.0
+    Example of usage:
+
+    .. code-block:: yaml
+
+        site0-webapp-setting:
+            win_iis.set_app:
+                - name: app0
+                - site: Default Web Site
+                - settings:
+                    userName: domain\user
+                    password: pass
+                    physicalPath: c:\inetpub\wwwroot
+                    applicationPool: appPool0
+    '''
+    ret = {'name': name,
+           'changes': {},
+           'comment': str(),
+           'result': None}
+
+    if not settings:
+        ret['comment'] = 'No settings to change provided.'
+        ret['result'] = True
+        return ret
+
+    ret_settings = {
+        'changes': {},
+        'failures': {},
+    }
+
+    current_settings = __salt__['win_iis.get_webapp_settings'](name=name,
+                                                                 site=site,
+                                                                 settings=settings.keys())
+    for setting in settings:
+        if str(settings[setting]) != str(current_settings[setting]):
+            ret_settings['changes'][setting] = {'old': current_settings[setting],
+                                                'new': settings[setting]}
+    if not ret_settings['changes']:
+        ret['comment'] = 'Settings already contain the provided values.'
+        ret['result'] = True
+        return ret
+    elif __opts__['test']:
+        ret['comment'] = 'Settings will be changed.'
+        ret['changes'] = ret_settings
+        return ret
+
+    __salt__['win_iis.set_webapp_settings'](name=name, site=site,
+                                              settings=settings)
+    new_settings = __salt__['win_iis.get_webapp_settings'](name=name, site=site, settings=settings.keys())
+
+    for setting in settings:
+        if str(settings[setting]) != str(new_settings[setting]):
+            ret_settings['failures'][setting] = {'old': current_settings[setting],
+                                                 'new': new_settings[setting]}
+            ret_settings['changes'].pop(setting, None)
+
+    if ret_settings['failures']:
+        ret['comment'] = 'Some settings failed to change.'
+        ret['changes'] = ret_settings
+        ret['result'] = False
+    else:
+        ret['comment'] = 'Set settings to contain the provided values.'
+        ret['changes'] = ret_settings['changes']
+        ret['result'] = True
+
+    return ret
